<?php
// Add thumbnail support to the theme.
add_theme_support('post-thumbnails', array('post'));
set_post_thumbnail_size(472, 130, true);

// Add the full-size image for a post.
add_image_size('single-post-thumbnail', 472, 9999, true);

// We need to intercept the form fields, in order to apply some of the custom
// styling to it. This is where we pass it through the custom functions.
add_filter('comment_form_field_author', 'ccd_comment_form_author');
add_filter('comment_form_field_email', 'ccd_comment_form_email');
add_filter('comment_form_field_url', 'ccd_comment_form_url');

// When we say we want comments, we only want comments - not pings. So the theme's
// comment function will sift through comments, and only give true comments.
// ccd_get_pings_number() is provided to get the number of pings.
add_filter('get_comments_number', 'ccd_get_comments_number', 0);

// Let's add a configuration menu for the theme.
add_action('admin_menu', 'ccd_admin_menu');

// Let's add the callback for the wp_footer() function call.
add_filter('wp_footer', 'ccd_wp_footer');

// Let's add a callback for the wp_head() function call.
add_filter('wp_head', 'ccd_wp_head');


/**
 * Provides the facility to display additional information before the closing
 * <body> tag. Used to display any analytics tracking code should there be
 * any required.
 */
function ccd_wp_footer() {
	$analytics = trim(get_option('ccd.analytics'));
	if ($analytics != '') {
		echo $analytics;
	}
}


/**
 * Used as the callback to process the wp_head hook. Displays any additional CSS
 * code should there be any defined.
 */
function ccd_wp_head() {
	$css = trim(get_option('ccd.additional_css'));
	if ($css != '') {
		echo '<style type="text/css">';
		echo $css;
		echo '</style>';
	}
}


/**
 * Hook used to add the theme's configuration page as a submenu to the administration
 * menu panel.
 */
function ccd_admin_menu() {
	add_submenu_page('themes.php', 'Candy-Coated Darkness Options', 'Candy-Coated Darkess', 'edit_theme_options', 'candy-coated-darkness-options', 'ccd_admin_page');
}


/**
 * The function used to generate and process the configuration options page. If
 * the page's form has been submitted, all the options are saved to the database.
 */
function ccd_admin_page() {
	if (!current_user_can('edit_theme_options')) {
		wp_die('You do not have the necessary permissions to view this page.');
	}

	if (isset($_POST['ccd']) && is_array($_POST['ccd'])) {
		foreach ($_POST['ccd'] as $optionName => $optionValue) {
			$optionValue = stripslashes($optionValue);
			update_option("ccd.{$optionName}", $optionValue);
		}

		echo '<div id="message" class="updated"><p><strong>Settings updated.</strong></p></div>';
	}
	?>
<div class="wrap">
	<h2>Candy-Coated Darkness Options</h2>
	<form method="post" action="">
		<table class="form-table">
			<tr>
				<th>Additional CSS Styles</th>
				<td>
					<textarea cols="80" rows="5" name="ccd[additional_css]"><?php echo esc_html(get_option('ccd.additional_css', ''));?></textarea>
					<p class="description">Use to override certain CSS styles supplied by the theme.</p>
				</td>
			</tr>
			<tr>
				<th>Analytics Tracking</th>
				<td>
					<textarea cols="80" rows="5" name="ccd[analytics]"><?php echo htmlentities(get_option('ccd.analytics', ''));?></textarea>
					<p class="description">Use to include your analytics and tracking code. &lt;script&gt; tags are <strong>not</strong> automatically included. You will need to include these yourself.</p>
				</td>
			</tr>
			<tr>
				<th>&nbsp;</th>
				<td>
					<p class="submit"><input class="button-primary" type="submit" value="Save Changes" name="Save" /></p>
				</td>
			</tr>
		</table>
	</form>
</div>
	<?php
}


/**
 * The central loop function, which is used to iterate over all of the posts
 * that are available on the current page. The layout for displaying the different
 * posts is changed based on the type of page being displayed.
 */
function ccd_loop() {
	while (have_posts()) {
		the_post();

		$class = 'block';
		
		if (get_post_type() != 'page' && !get_next_post()) {
			$class .= ' sash-latest-post';
		}

		if (get_post_type() == 'page') {
			$class .= ' sash-page';
		}
		
		echo '<div class="'. $class .'">';
		if (has_post_thumbnail()) {
			echo sprintf('<div class="image"><a href="%s" title="%s">%s</a></div>', get_post_permalink(), get_the_title(), get_the_post_thumbnail(null, 'post-thumbnail', array('title' => 'Read "'. get_the_title() .'"')));
		}

		echo sprintf('<span class="posted">%s</span>', get_the_time('d M, Y'));
		echo sprintf('<h2><a href="%s" title="%2$s">%2$s</a></h2>', get_post_permalink(), get_the_title());

		echo '<div class="content">';
			has_excerpt() ? the_excerpt() : the_content(false, 1);
			echo sprintf('<a href="%s" class="read-more" title="Read more">Read more &rarr;</a>', get_post_permalink());
		echo '</div>';
		
		echo '</div>';
	}
}


/**
 * Gets the number of comments on the current post.
 * @global int $id
 * @return int
 */
function ccd_get_comments_number() {
	global $id;
	$_c = separate_comments(get_comments("post_id={$id}&status=approve"));
	return count($_c['comment']);
}


/**
 * Gets the number of pingbacks on the current post.
 * @global int $id
 * @return int
 */
function ccd_get_pings_number() {
	global $id;
	$_c = separate_comments(get_comments("post_id={$id}&status=approve"));
	return count($_c['pings']);
}


/**
 * Outputs the list of pingbacks for the current post.
 * @return void
 */
function ccd_post_pings() {
	if (ccd_get_pings_number() <= 0) {
		echo 'There are no pingbacks on this post yet.';
		return;
	}

	while (have_comments()) {
		the_comment();

		if (get_comment_type() == '' || get_comment_type() == 'comment') {
			continue;
		}

		echo '<div class="pingback">';
			echo sprintf('<span class="poster">Pingback from %s</span>', get_comment_author());
			echo sprintf('<span class="posted">%s</span>', get_comment_time('d M, Y \a\t H\hi'));
			echo sprintf('<p class="pingback-url"><a href="%1$s" target="_blank">%1$s</a></p>', get_comment_author_url());
		echo '</div>';
	}
}


/**
 * Displays the list of post comments.
 * @return void
 */
function ccd_post_comments() {
	if (get_comments_number() <= 0) {
		echo 'There are no comments on this post yet.';
		return;
	}

	$i = 0;
	while (have_comments()) {
		the_comment();

		if (get_comment_type() != 'comment') {
			continue;
		}

		if ($i++ > 0) {
			echo '<hr />';
		}

		$gravatar = get_avatar(get_comment_author_email(), '50');

		echo '<div class="comment">';
		if ($gravatar) {
			echo sprintf('<div class="gravatar">%s</div>', $gravatar);
		}

		if (get_comment_author_url() != '') {
			echo sprintf('<a class="poster" target="_blank" href="%s">%s</a>', get_comment_author_url(), get_comment_author());
		} else {
			echo sprintf('<span class="poster">%s</span>', get_comment_author());
		}

		echo sprintf('<span class="posted">%s</span>', get_comment_time('d M, Y \a\t H\hi'));
		echo '<div class="comment-body">';
			comment_text();
		echo '</div>';

		echo '</div>';
	}
}


/**
 * Displays the tab used to switch between viewing pingbacks and viewing comments.
 * @return void
 */
function ccd_comment_pings_tabs() {
	if (!comments_open() && !pings_open()) {
		return;
	}

	echo '<ul class="switcher">';
	if (comments_open()) {
		if (pings_open()) {
			echo sprintf('<li class="comments"><a href="#" class="selected">Comments (%d)</a></li>', get_comments_number());
		} else {
			echo sprintf('<li class="comments comments-only"><span class="selected">Comments (%d)</span></li>', get_comments_number());
		}
	}

	if (pings_open()) {
		if (comments_open()) {
			echo sprintf('<li class="pingbacks"><a href="#">Pings (%d)</a></li>', ccd_get_pings_number());
		} else {
			echo sprintf('<li class="pingbacks pingbacks-only"><span>PIngs (%d)</span></li>', ccd_get_pings_number());
		}
	}

	echo '</ul>';
}


/**
 * Outputs the form used to add comments.
 * @global string $user_identity The current user's username.
 */
function ccd_comment_form() {
	$args['label_submit'] = 'Add Comment';
	$args['title_reply'] = '';
	$args['comment_notes_after'] = '';
	$args['comment_field'] = '<div class="input"><label for="comment">Comment</label><textarea id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea></div>';
	$args['comment_notes_before'] = '';

	global $user_identity;
	$loggedInAs = '<p class="notes">You are currently logged in as <a href="%1$s">%2$s</a>. Would you like to <a href="%3$s" title="Log out of this account">log out</a> and change users?</p>';
	$loggedInAs = sprintf($loggedInAs, admin_url('profile.php'), $user_identity, wp_logout_url(get_post_permalink()));
	$args['logged_in_as'] = $loggedInAs;

	comment_form($args);
}


/**
 * Displays the pagination for post listings, should there be the need.
 * @access public
 * @static
 * @uses $wp_query
 * @return void
 */
function ccd_pagination() {
	global $wp_query;
	if ($wp_query->max_num_pages <= 1) {
		return;
	}

	echo '<ul id="pagination">';
		echo '<li class="prev">'. get_next_posts_link('&larr; Older Entries') .'</li>';
		echo '<li class="next">'. get_previous_posts_link('Newer Entries &rarr;') .'</li>';
	echo '</ul>';
}


/**
 * Displays a block of the latest posts to be added.
 */
function ccd_latest_posts() {
	$latestPosts = get_posts();
	if (!empty($latestPosts)) {
		echo '<div class="block latest-posts">';
		echo '<h1>Latest Posts</h1>';
		foreach ($latestPosts as $post) {
			echo '<p>';
			echo '<a href="'. get_post_permalink($post->ID) .'">';
			echo $post->post_title;
			echo sprintf('<span class="posted">%s</span>', date('d M, Y', strtotime($post->post_date)));
			echo '</a>';
			echo '</p>';
		}
		echo '</div>';
	}
}


/**
 * Generates the navigation for the blog. The type of navigation is needed, as
 * it determines whether the RSS link is an image or is plaintext.
 * @param string $type The type of navigation being displayed.
 * @return void
 */
function ccd_navigation($type) {
	echo '<ul>';
	echo '<li><a href="'. get_bloginfo('url') .'/" title="Home">Home</a></li>';
	wp_list_pages(array('title_li' => false, 'depth' => 1));
	if ($type == 'footer') {
		$rssLinkContent = 'RSS';
	} else {
		$rssLinkContent = '<img src="'. get_bloginfo('template_url') .'/img/rss-large.png" width="28" height="28" alt="RSS" />';
	}
	if ($type == 'footer') {
		echo '<li class="rss"><a href="'. get_bloginfo('rss_url') .'" title="RSS feed for blog posts">'. $rssLinkContent .'</a></li>';
	}
	echo '</ul>';
}


/**
 * Intercepts the author input field from the comment form, and reformats it to
 * fit the theme's layout.
 * @param string $originalField The HTML for the original form input.
 * @return string The modified form input field.
 */
function ccd_comment_form_author($originalField) {
	$required = false;
	if (stripos($originalField, "aria-required='true'") !== false) {
		$required = true;
	}
	$output = '<div class="input comment-form-author">';
	$output .= '<label for="author">Name';
	if ($required) {
		$output .= ' <span class="required">* Required</span>';
	}
	$output .= '</label>';
	$output .= '<input id="author" type="text" size="30" name="author" />';
	$output .= '</div>';

	return $output;
}


/**
 * Intercepts the email input field from the comment form, and reformats it to
 * fit the theme's layout.
 * @param string $originalField The HTML for the original form input.
 * @return string The modified form input field.
 */
function ccd_comment_form_email($originalField) {
	$required = false;
	if (stripos($originalField, "aria-required='true'") !== false) {
		$required = true;
	}
	$output = '<div class="input comment-form-email">';
	$output .= '<label for="email">Email';
	if ($required) {
		$output .= ' <span class="required">* Required</span>';
	}
	$output .= '</label>';
	$output .= '<input id="email" type="text" size="30" name="email" />';
	$output .= '</div>';

	return $output;
}


/**
 * Intercepts the URL input field from the comment form, and reformats it to
 * fit the theme's layout.
 * @param string $originalField The HTML for the original form input.
 * @return string The modified form input field.
 */
function ccd_comment_form_url($originalField) {
	$required = false;
	if (stripos($originalField, "aria-required='true'") !== false) {
		$required = true;
	}
	$output = '<div class="input comment-form-url">';
	$output .= '<label for="url">Website URL';
	if ($required) {
		$output .= ' <span class="required">* Required</span>';
	}
	$output .= '</label>';
	$output .= '<input id="url" type="text" size="30" name="url" />';
	$output .= '</div>';

	return $output;
}